@@ -1,8 +1,8 @@
 #![no_main]
 #![no_std]
 
-// This exemple should be used with simple_rtt_tag exemple and is the
-// implementation of RTT localisation process
+// This exemple should be used with simple_rtt_tag exemple and is the implementation of 
+// RTT localisation process
 
 use panic_rtt_target as _;
 use rtt_target::{rprintln, rtt_init_print};
@@ -96,9 +96,7 @@ fn main() -> ! {
 		.expect("Failed init.");
 	//rprintln!("dm3000 = {:?}", dw3000);
 
-	dw3000
-		.set_antenna_delay(0, 0)
-		.expect("Failed set antenna delay.");
+	dw3000.set_antenna_delay(0,0).expect("Failed set antenna delay.");
 
 	loop {
 		/**************************** */
@@ -107,10 +105,15 @@ fn main() -> ! {
 		// let delayed_tx_time = dw3000.sys_time().expect("Failed to get time");
 		delay.delay_ms(5000_u32);
 		let mut sending = dw3000
-			.send(&[1, 2, 3, 4, 5], hl::SendTime::Now, Config::default())
+			.send(
+				&[1, 2, 3, 4, 5],
+				hl::SendTime::Now,
+				Config::default(),
+			)
 			.expect("Failed configure transmitter");
 		let result = block!(sending.s_wait());
-		let t1: u64 = result.unwrap().value();
+		let t1:u64 = result.unwrap().value();
+
 
 		// on affiche le resultat
 		//rprintln!("Trame envoyée !!!\n");
@@ -136,13 +139,13 @@ fn main() -> ! {
 			.finish_receiving()
 			.expect("Failed to finish receiving");
 		let result = result.unwrap();
-		let t4: u64 = result.rx_time.value();
+		let t4:u64 = result.rx_time.value();
 		let x = result.frame.payload;
-		let t2: u64 = ((x[0] as u64) << (8 * 4))
-			+ ((x[1] as u64) << (8 * 3))
-			+ ((x[2] as u64) << (8 * 2))
-			+ ((x[3] as u64) << (8 * 1))
-			+ (x[4] as u64);
+		let t2: u64 = ((x[0] as u64) << (8 * 4)) 
+					+ ((x[1] as u64) << (8 * 3))
+					+ ((x[2] as u64) << (8 * 2))
+					+ ((x[3] as u64) << (8 * 1))
+					+ (x[4] as u64);
 		//rprintln!("data = {:x?}", x);
 		//rprintln!("data = {:x?}", t2);
 
@@ -157,17 +160,17 @@ fn main() -> ! {
 			.finish_receiving()
 			.expect("Failed to finish receiving");
 		let x = result.unwrap().frame.payload;
-		let t3: u64 = ((x[0] as u64) << (8 * 4))
-			+ ((x[1] as u64) << (8 * 3))
-			+ ((x[2] as u64) << (8 * 2))
-			+ ((x[3] as u64) << (8 * 1))
-			+ (x[4] as u64);
+		let t3: u64 = ((x[0] as u64) << (8 * 4)) 
+					+ ((x[1] as u64) << (8 * 3))
+					+ ((x[2] as u64) << (8 * 2))
+					+ ((x[3] as u64) << (8 * 1))
+					+ (x[4] as u64);
 
 		rprintln!("T1 = {:?}", t1);
 		rprintln!("T2 = {:?}", t2);
 		rprintln!("T3 = {:?}", t3);
 		rprintln!("T4 = {:?}", t4);
-		rprintln!("distance = {:?}\n\n", ((t4 - t1 - t3 + t2) / 2) as i64); // speed in ns
-		                                                            // (((result_time - transmit_time - 320_000_000)as f64 * 299.792_458) / 128.0) as u64);
+		rprintln!("distance = {:?}\n\n", ((t4-t1-t3+t2) / 128) as i64); // speed in ns
+		// (((result_time - transmit_time - 320_000_000)as f64 * 299.792_458) / 128.0) as u64);
 	}
 }
